local addonName, TF = ...

local TradeFill = LibStub("AceAddon-3.0"):GetAddon(addonName)
local Loc = LibStub("AceLocale-3.0"):GetLocale(addonName)

function TradeFill:Message(message, arg1, arg2, condition)
    if TF.setting.message then
        return
    else
        for _, oldMessage in pairs(TF.messages) do
            if oldMessage == arg1 then
                return
            end
        end

        if condition then
            DEFAULT_CHAT_FRAME:AddMessage(TF.signature .. string.format(Loc["CONDITION_MESSAGE"] .. message, arg1, arg2))
        else
            DEFAULT_CHAT_FRAME:AddMessage(TF.signature .. string.format(message, arg1))
        end
        table.insert(TF.messages, arg1)
    end
end

function TradeFill:checkStacks(stackTable)
    if next(stackTable) == nil then
        return true
    end

    for _, value in pairs(stackTable) do
        if type(value) == "table" then
            if not TradeFill:checkStacks(value) then
                return false
            end
        elseif value ~= 0 then
            return false
        end
    end
    return true
end

function TradeFill:ItemCondition(stack, item, index)
    local linkIcon = item.link .. " |T" .. C_Item.GetItemIconByID(item.id) .. ":0|t"

    if tonumber(item.limit) > 0 then
        if TradeFill.limit.profile[TF.fullName][tostring(index)] then
            local limit = TradeFill.limit.profile[TF.fullName][tostring(index)]

            if limit >= tonumber(item.limit) then
                TradeFill:Message(Loc["MESSAGE_LIMIT"], linkIcon, TradeFill:SetName(), true)
                return
            end
        end
    end

    if TF.setting.require == true and  TF.level < item.level then
        TradeFill:Message(Loc["MESSAGE_REQUIRED"], linkIcon, Loc["TOGGLE_REQUIRED"], true)
        return
    else
        for _ = 1, stack do
            TradeFill:AutoFill(item, TradeFrame_GetAvailableSlot())
        end
    end
end

function TradeFill:TradingCondition()
    local flagg = false
    local maxLevel = GetMaxPlayerLevel()

    if TF.setting.auto == false then
        TradeFill:Message(Loc["MESSAGE_AUTOFILL"], Loc["THESE_ITEMS"], Loc["TOGGLE_AUTOFILL"], true)
        return true
    end

    if TF.setting.guild == true then
        if GetGuildInfo("player") == nil then
            TradeFill:Message(Loc["MESSAGE_NO_GUILD"], Loc["THESE_ITEMS"], Loc["TOGGLE_GUILD"], true)
            flagg = true
        elseif TF.guild ~= GetGuildInfo("player") then
            TradeFill:Message(Loc["MESSAGE_GUILD"], Loc["THESE_ITEMS"], Loc["TOGGLE_GUILD"], true)
            flagg = true
        end
    end

    if TF.setting.level == true and TF.level ~= maxLevel then
        TradeFill:Message(Loc["MESSAGE_LEVEL"], Loc["THESE_ITEMS"], TradeFill:GetMaxPlayerLevel(), true)
        flagg = true
    end

    if TradeFill:checkStacks(TF.stack) then
        TradeFill:Message(Loc["MESSAGE_STACK_CLASS"], Loc["THESE_ITEMS"], TradeFill:SetClass(TF.class.file), true)
        flagg = true
    end

    for name in string.gmatch(TF.setting.players, "[^\n]+") do
        if string.lower(name) == string.lower(TF.name) then
            TradeFill:Message(Loc["MESSAGE_EXCLUDE_PLAYERS"], Loc["THESE_ITEMS"], TradeFill:SetName(), true)
            flagg = true
        end
    end

    if TF.guild then
        for guild in string.gmatch(TF.setting.guilds, "[^\n]+") do
            if string.lower(guild) == string.lower(TF.guild) then
                local guildName = TF.guild

                TradeFill:Message(Loc["MESSAGE_EXCLUDE_GUILDS"], Loc["THESE_ITEMS"], "|cFF00FF00" .. guildName .. "|r", true)
                flagg = true
            end
        end
    end

    if TF.setting.master == true then
        local lootmethod, mlPartyID, mlRaidID = GetLootMethod()
        local newLootMaster = nil

        if lootmethod == 'master' then
            if mlRaidID then
                newLootMaster = GetRaidRosterInfo(mlRaidID)
            elseif mlPartyID==0 then
                newLootMaster = UnitName('player')
            elseif mlPartyID then
                newLootMaster = UnitName('party'..mlPartyID)
            end

            if UnitName("player") == newLootMaster then
                TradeFill:Message(Loc["MESSAGE_MASTER_LOOTER"], Loc["THESE_ITEMS"], nil, true)
                flagg = true
            end
        end
    end
    return flagg
end